aboutsummaryrefslogtreecommitdiff
path: root/src/os/executable_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/os/executable_test.go')
-rw-r--r--src/os/executable_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/os/executable_test.go b/src/os/executable_test.go
index 4a9a8837be..d513c8760e 100644
--- a/src/os/executable_test.go
+++ b/src/os/executable_test.go
@@ -36,8 +36,8 @@ func TestExecutable(t *testing.T) {
// forge argv[0] for child, so that we can verify we could correctly
// get real path of the executable without influenced by argv[0].
cmd.Args = []string{"-", "-test.run=XXXX"}
- if runtime.GOOS == "openbsd" {
- // OpenBSD relies on argv[0]
+ if runtime.GOOS == "openbsd" || runtime.GOOS == "aix" {
+ // OpenBSD and AIX rely on argv[0]
cmd.Args[0] = fn
}
cmd.Env = append(os.Environ(), fmt.Sprintf("%s=1", executable_EnvVar))